@@ -1,4 +1,3 @@
-
 #' Function to bind objects together into a longer object.
 #'
 #' From multiple \code{download*}s, \code{dataset*}s or \code{site}s, join them together into a single object.
@@ -16,9 +15,9 @@
 #' @examples \dontrun{
 #' #  Search for sites with "Thuja" pollen that are older than 8kyr BP and
 #' #  that are on the west coast of North America:
-#' t8kyr.poa <- get_dataset(taxonname='Thuja*', 
+#' t8kyr.poa <- get_dataset(taxonname="Thuja*", 
 #'                          loc=c(-150, 20, -100, 60), ageyoung = 8000)
-#' t8kyr.canis <- get_dataset(taxonname='Canis*', 
+#' t8kyr.canis <- get_dataset(taxonname="Canis*", 
 #'                            loc=c(-150, 20, -100, 60), ageyoung = 8000)
 #'
 #' t8kyr.co_site <- bind(t8kyr.poa, t8kyr.canis)
@@ -27,19 +26,19 @@
 #' ####
 #' # Download dataset data across four dataset types along the forest prairie boundary:
 #' # We want to look at four different dataset types across a forest prairie boundary:
-#' dataset_types <- c('ostracode surface sample',
-#'                    'water chemistry',
-#'                    'diatom surface sample',
-#'                    'pollen surface sample')
+#' dataset_types <- c("ostracode surface sample",
+#'                    "water chemistry",
+#'                    "diatom surface sample",
+#'                    "pollen surface sample")
 #' 
-#' # Run the 'get_dataset` function for each of the different dataset types 
+#' # Run the "get_dataset` function for each of the different dataset types 
 #' dataset_lists <- lapply(dataset_types, 
 #'                           function(x) { 
 #'                             get_dataset(datasettype=x, 
 #'                                         loc = c(-100,43,-92,48))
 #'                                         })
 #' 
-#' # Using do.call here to make sure that I don't have to split the list out.
+#' # Using do.call here to make sure that I don"t have to split the list out.
 #' new_datasets <- do.call(bind, dataset_lists)
 #' 
 #' # And voila!
@@ -52,70 +51,76 @@
 #' @keywords utilities
 #' @export
 
-bind <- function(x, ...) {
-  
+bind <- function(x, ...){
+  UseMethod('bind')
+}
+
+#' @export
+bind.default <- function(x, ...) {
+
   inputs <- list(x, ...)
-  
-  if (!length(inputs)>1) {
-    # If there's only one element, make sure it's a list and that the 
+
+  if (!length(inputs) > 1) {
+    # If there"s only one element, make sure it"s a list and that the
     # classes within the list are equivalent.
     inputs <- x
-    if ('list' %in% class(inputs)) {
+    if ("list" %in% class(inputs)) {
       list_class <- sapply(inputs, class)
-      if (do.call(all.equal, as.list(list_class[1,]))) {
+      if (do.call(all.equal, as.list(list_class[1, ]))) {
         # All datasets are of the same type:
         return(do.call(bind, inputs))
       } else {
-        stop('All list elements must be of the same type.')
+        stop("All list elements must be of the same type.")
       }
     } else{
-      stop('When passing a single object, that object must be a list of all the same data type.')
+      stop(paste0("When passing a single object, that object must be a list ",
+                  "of all the same data type."))
     }
   }
-  
+
   classes <- sapply(inputs, function(x)unlist(class(x)))
-  
-  if (all(classes[1,] == 'download_list')) {
+
+  if (all(classes[1,] == "download_list")) {
     new.list <- do.call(c, inputs)
-    class(new.list) <- c('download_list', 'list')
+    class(new.list) <- c("download_list", "list")
     return(new.list)
-  } else if (all(classes[1,] == 'dataset_list')) {
+  } else if (all(classes[1,] == "dataset_list")) {
     new.list <- do.call(c, inputs)
-    class(new.list) <- c('dataset_list', 'list')
+    class(new.list) <- c("dataset_list", "list")
     return(new.list)
-  } else if (all(classes[1,] == 'site')) {
+  } else if (all(classes[1,] == "site")) {
     new.list <- do.call(rbind.data.frame, inputs)
-    class(new.list) <- c('site', 'data.frame')
+    class(new.list) <- c("site", "data.frame")
     return(new.list)
-  } else if (!all(classes[1,] == 'download_list') & all(classes[1,] %in% c('download_list', 'download'))) {
+  } else if (!all(classes[1,] == "download_list") & all(classes[1,] %in% c("download_list", "download"))) {
     #  Turn them into download_lists first.
     inputs <- lapply(inputs, function(x) {
-      if (class(x)[1] == 'download') {
+      if (class(x)[1] == "download") {
         x <- list(x)
-        class(x) <- c('download_list', 'list')
+        class(x) <- c("download_list", "list")
       }
       x})
     
     new.list <- do.call(c, inputs)
-    class(new.list) <- c('download_list', 'list')
+    class(new.list) <- c("download_list", "list")
     return(new.list)
     
-  } else if (!all(classes[1,] == 'dataset_list') & all(classes[1,] %in% c('dataset_list', 'dataset'))) {
+  } else if (!all(classes[1,] == "dataset_list") & all(classes[1,] %in% c("dataset_list", "dataset"))) {
     #  Turn them into dataset_lists first.
     x <- lapply(inputs, function(x) {
-      if (class(x)[1] == 'dataset') {
+      if (class(x)[1] == "dataset") {
         x <- list(x)
-        class(x) <- c('dataset_list', 'list')
+        class(x) <- c("dataset_list", "list")
       }
       x})
 
     new.list <- do.call(c, inputs)
-    class(new.list) <- c('dataset_list', 'list')
+    class(new.list) <- c("dataset_list", "list")
     return(new.list)
     
   }
   else {
-    stop('Objects must be of the same class (or related "_list" classes)')
+    stop("Objects must be of the same class (or related '_list' classes)")
   }
   
 }
\ No newline at end of file
